==> impresence-plugin-3.0.0-sources.jar: com/atlassian/confluence/extra/impresence2/reporter/WildfirePresenceReporter.java <==
/*
 * Copyright (c) 2006, Atlassian Software Systems Pty Ltd
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of "Atlassian" nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.atlassian.confluence.extra.impresence2.reporter;

import static org.apache.commons.lang.StringUtils.isNotBlank;

import java.io.IOException;

import com.atlassian.confluence.util.GeneralUtil;
import com.atlassian.renderer.v2.RenderUtils;

/**
 * Reports on Jive Wildfire presence.
 */
public class WildfirePresenceReporter extends ServerPresenceReporter
{

    public static final String KEY = "wildfire";

    public String getKey()
    {
        return KEY;
    }

    public String getName()
    {
        return getText("presencereporter.wildfire.name");
    }

    public String getServiceHomepage()
    {
        return getText("presencereporter.wildfire.servicehomepage");
    }

    public String getPresenceXHTML(String id, boolean outputId) throws IOException, PresenceException
    {
        if (!isNotBlank(id))
        {
            return RenderUtils.error(getText("presencereporter.wildfire.error.noscreename"));
        }

        StringBuffer out = new StringBuffer();

        out.append("<a href='jabber:").append(id).append("'")
           .append(" title='Online status for ").append(id).append("'")
           .append(" style='white-space:nowrap;'>");

        out.append("<img src='http://").append(GeneralUtil.htmlEncode(getServer())).append("/plugins/presence/status?jid=").append(id).append("'")
           .append(" align='absmiddle' border='0' title='Status Indicator' alt='Status Indicator'/>");

        out.append("</a>");
        if (outputId)
        {
            out.append("&nbsp;<a href='jabber:").append(id).append("'")
                .append(" title='Online status for ").append(id).append("'")
                .append(" style='white-space:nowrap;'>").append(id).append("</a>");
        }

        return out.toString();
    }

}

==> impresence-plugin-4.0.3-sources.jar: com/atlassian/confluence/extra/impresence2/reporter/WildfirePresenceReporter.java <==
/*
 * Copyright (c) 2006, Atlassian Software Systems Pty Ltd
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of "Atlassian" nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.atlassian.confluence.extra.impresence2.reporter;

import com.atlassian.bandana.BandanaManager;
import com.atlassian.confluence.extra.impresence2.util.LocaleSupport;
import com.atlassian.confluence.util.GeneralUtil;
import com.atlassian.renderer.v2.RenderUtils;

import java.io.IOException;

import static org.apache.commons.lang3.StringUtils.isNotBlank;

/**
 * Reports on Jive Wildfire presence.
 */
public class WildfirePresenceReporter extends ServerPresenceReporter
{

    public static final String KEY = "wildfire";

    public WildfirePresenceReporter(LocaleSupport localeSupport, BandanaManager bandanaManager) {
        super(localeSupport, bandanaManager);
    }

    public String getKey()
    {
        return KEY;
    }

    public String getName()
    {
        return getText("presencereporter.wildfire.name");
    }

    public String getServiceHomepage()
    {
        return getText("presencereporter.wildfire.servicehomepage");
    }

    public String getPresenceXHTML(String id, boolean outputId) throws IOException, PresenceException
    {
        if (!isNotBlank(id))
        {
            return RenderUtils.error(getText("presencereporter.wildfire.error.noscreename"));
        }

        StringBuffer out = new StringBuffer();

        out.append("<a href='jabber:").append(id).append("'")
           .append(" title='Online status for ").append(id).append("'")
           .append(" style='white-space:nowrap;'>");

        out.append("<img src='http://").append(GeneralUtil.htmlEncode(getServer())).append("/plugins/presence/status?jid=").append(id).append("'")
           .append(" align='absmiddle' border='0' title='Status Indicator' alt='Status Indicator'/>");

        out.append("</a>");
        if (outputId)
        {
            out.append("&nbsp;<a href='jabber:").append(id).append("'")
                .append(" title='Online status for ").append(id).append("'")
                .append(" style='white-space:nowrap;'>").append(id).append("</a>");
        }

        return out.toString();
    }

}
